# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: camera.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "camera.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import media_pb2 as media__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0c\x63\x61mera.proto\x12\x0chazel.rpc.v1\x1a\x0c\x63ommon.proto\x1a\x0bmedia.proto">\n\nCameraInfo\x12"\n\x02id\x18\x01 \x01(\x0b\x32\x16.hazel.rpc.v1.EntityId\x12\x0c\n\x04name\x18\x02 \x01(\t"\x14\n\x12ListCamerasRequest"@\n\x13ListCamerasResponse\x12)\n\x07\x63\x61meras\x18\x01 \x03(\x0b\x32\x18.hazel.rpc.v1.CameraInfo"\x9c\x01\n\x13StreamCameraRequest\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x16.hazel.rpc.v1.EntityIdH\x00\x12\x0e\n\x04name\x18\x02 \x01(\tH\x00\x12\x12\n\ntarget_fps\x18\x03 \x01(\r\x12\r\n\x05width\x18\x04 \x01(\r\x12\x0e\n\x06height\x18\x05 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\tB\x0c\n\nidentifier2\xb2\x01\n\rCameraService\x12R\n\x0bListCameras\x12 .hazel.rpc.v1.ListCamerasRequest\x1a!.hazel.rpc.v1.ListCamerasResponse\x12M\n\x0cStreamCamera\x12!.hazel.rpc.v1.StreamCameraRequest\x1a\x18.hazel.rpc.v1.ImageFrame0\x01\x42\x03\xf8\x01\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\370\001\001"
    _globals["_CAMERAINFO"]._serialized_start = 57
    _globals["_CAMERAINFO"]._serialized_end = 119
    _globals["_LISTCAMERASREQUEST"]._serialized_start = 121
    _globals["_LISTCAMERASREQUEST"]._serialized_end = 141
    _globals["_LISTCAMERASRESPONSE"]._serialized_start = 143
    _globals["_LISTCAMERASRESPONSE"]._serialized_end = 207
    _globals["_STREAMCAMERAREQUEST"]._serialized_start = 210
    _globals["_STREAMCAMERAREQUEST"]._serialized_end = 366
    _globals["_CAMERASERVICE"]._serialized_start = 369
    _globals["_CAMERASERVICE"]._serialized_end = 547
# @@protoc_insertion_point(module_scope)
