# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import mujoco_pb2 as mujoco__pb2

GRPC_GENERATED_VERSION = "1.76.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(
        GRPC_VERSION, GRPC_GENERATED_VERSION
    )
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + " but the generated code in mujoco_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class MujocoServiceStub(object):
    """MuJoCo state + control IO."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetJointState = channel.unary_unary(
            "/hazel.rpc.v1.MujocoService/GetJointState",
            request_serializer=mujoco__pb2.GetJointStateRequest.SerializeToString,
            response_deserializer=mujoco__pb2.GetJointStateResponse.FromString,
            _registered_method=True,
        )
        self.SendControl = channel.unary_unary(
            "/hazel.rpc.v1.MujocoService/SendControl",
            request_serializer=mujoco__pb2.SendControlRequest.SerializeToString,
            response_deserializer=mujoco__pb2.SendControlResponse.FromString,
            _registered_method=True,
        )
        self.GetMujocoInfo = channel.unary_unary(
            "/hazel.rpc.v1.MujocoService/GetMujocoInfo",
            request_serializer=mujoco__pb2.GetMujocoInfoRequest.SerializeToString,
            response_deserializer=mujoco__pb2.GetMujocoInfoResponse.FromString,
            _registered_method=True,
        )
        self.StreamJointState = channel.unary_stream(
            "/hazel.rpc.v1.MujocoService/StreamJointState",
            request_serializer=mujoco__pb2.GetJointStateRequest.SerializeToString,
            response_deserializer=mujoco__pb2.GetJointStateResponse.FromString,
            _registered_method=True,
        )


class MujocoServiceServicer(object):
    """MuJoCo state + control IO."""

    def GetJointState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SendControl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetMujocoInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamJointState(self, request, context):
        """Streaming variant for continuous state observation"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_MujocoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetJointState": grpc.unary_unary_rpc_method_handler(
            servicer.GetJointState,
            request_deserializer=mujoco__pb2.GetJointStateRequest.FromString,
            response_serializer=mujoco__pb2.GetJointStateResponse.SerializeToString,
        ),
        "SendControl": grpc.unary_unary_rpc_method_handler(
            servicer.SendControl,
            request_deserializer=mujoco__pb2.SendControlRequest.FromString,
            response_serializer=mujoco__pb2.SendControlResponse.SerializeToString,
        ),
        "GetMujocoInfo": grpc.unary_unary_rpc_method_handler(
            servicer.GetMujocoInfo,
            request_deserializer=mujoco__pb2.GetMujocoInfoRequest.FromString,
            response_serializer=mujoco__pb2.GetMujocoInfoResponse.SerializeToString,
        ),
        "StreamJointState": grpc.unary_stream_rpc_method_handler(
            servicer.StreamJointState,
            request_deserializer=mujoco__pb2.GetJointStateRequest.FromString,
            response_serializer=mujoco__pb2.GetJointStateResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "hazel.rpc.v1.MujocoService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "hazel.rpc.v1.MujocoService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class MujocoService(object):
    """MuJoCo state + control IO."""

    @staticmethod
    def GetJointState(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/hazel.rpc.v1.MujocoService/GetJointState",
            mujoco__pb2.GetJointStateRequest.SerializeToString,
            mujoco__pb2.GetJointStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def SendControl(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/hazel.rpc.v1.MujocoService/SendControl",
            mujoco__pb2.SendControlRequest.SerializeToString,
            mujoco__pb2.SendControlResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetMujocoInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/hazel.rpc.v1.MujocoService/GetMujocoInfo",
            mujoco__pb2.GetMujocoInfoRequest.SerializeToString,
            mujoco__pb2.GetMujocoInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StreamJointState(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/hazel.rpc.v1.MujocoService/StreamJointState",
            mujoco__pb2.GetJointStateRequest.SerializeToString,
            mujoco__pb2.GetJointStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
