# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: media.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "media.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0bmedia.proto\x12\x0chazel.rpc.v1"\x87\x01\n\nImageFrame\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\x10\n\x08\x63hannels\x18\x04 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x05 \x01(\t\x12\x14\n\x0ctimestamp_ms\x18\x06 \x01(\x04\x12\x14\n\x0c\x66rame_number\x18\x07 \x01(\r"H\n\x0fNamedImageFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\x05\x66rame\x18\x02 \x01(\x0b\x32\x18.hazel.rpc.v1.ImageFrameB\x03\xf8\x01\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "media_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\370\001\001"
    _globals["_IMAGEFRAME"]._serialized_start = 30
    _globals["_IMAGEFRAME"]._serialized_end = 165
    _globals["_NAMEDIMAGEFRAME"]._serialized_start = 167
    _globals["_NAMEDIMAGEFRAME"]._serialized_end = 239
# @@protoc_insertion_point(module_scope)
