# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mujoco.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "mujoco.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0cmujoco.proto\x12\x0chazel.rpc.v1"K\n\nJointState\x12\x11\n\tpositions\x18\x01 \x03(\x02\x12\x12\n\nvelocities\x18\x02 \x03(\x02\x12\n\n\x02nq\x18\x03 \x01(\r\x12\n\n\x02nv\x18\x04 \x01(\r"*\n\x14GetJointStateRequest\x12\x12\n\nrobot_name\x18\x01 \x01(\t"b\n\x15GetJointStateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\'\n\x05state\x18\x03 \x01(\x0b\x32\x18.hazel.rpc.v1.JointState":\n\x12SendControlRequest\x12\x12\n\nrobot_name\x18\x01 \x01(\t\x12\x10\n\x08\x63ontrols\x18\x02 \x03(\x02"7\n\x13SendControlResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t"*\n\x14GetMujocoInfoRequest\x12\x12\n\nrobot_name\x18\x01 \x01(\t"\x8a\x01\n\x15GetMujocoInfoResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\n\n\x02nq\x18\x03 \x01(\r\x12\n\n\x02nv\x18\x04 \x01(\r\x12\n\n\x02nu\x18\x05 \x01(\r\x12\x13\n\x0bjoint_names\x18\x06 \x03(\t\x12\x16\n\x0e\x61\x63tuator_names\x18\x07 \x03(\t2\xf6\x02\n\rMujocoService\x12X\n\rGetJointState\x12".hazel.rpc.v1.GetJointStateRequest\x1a#.hazel.rpc.v1.GetJointStateResponse\x12R\n\x0bSendControl\x12 .hazel.rpc.v1.SendControlRequest\x1a!.hazel.rpc.v1.SendControlResponse\x12X\n\rGetMujocoInfo\x12".hazel.rpc.v1.GetMujocoInfoRequest\x1a#.hazel.rpc.v1.GetMujocoInfoResponse\x12]\n\x10StreamJointState\x12".hazel.rpc.v1.GetJointStateRequest\x1a#.hazel.rpc.v1.GetJointStateResponse0\x01\x42\x03\xf8\x01\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "mujoco_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\370\001\001"
    _globals["_JOINTSTATE"]._serialized_start = 30
    _globals["_JOINTSTATE"]._serialized_end = 105
    _globals["_GETJOINTSTATEREQUEST"]._serialized_start = 107
    _globals["_GETJOINTSTATEREQUEST"]._serialized_end = 149
    _globals["_GETJOINTSTATERESPONSE"]._serialized_start = 151
    _globals["_GETJOINTSTATERESPONSE"]._serialized_end = 249
    _globals["_SENDCONTROLREQUEST"]._serialized_start = 251
    _globals["_SENDCONTROLREQUEST"]._serialized_end = 309
    _globals["_SENDCONTROLRESPONSE"]._serialized_start = 311
    _globals["_SENDCONTROLRESPONSE"]._serialized_end = 366
    _globals["_GETMUJOCOINFOREQUEST"]._serialized_start = 368
    _globals["_GETMUJOCOINFOREQUEST"]._serialized_end = 410
    _globals["_GETMUJOCOINFORESPONSE"]._serialized_start = 413
    _globals["_GETMUJOCOINFORESPONSE"]._serialized_end = 551
    _globals["_MUJOCOSERVICE"]._serialized_start = 554
    _globals["_MUJOCOSERVICE"]._serialized_end = 928
# @@protoc_insertion_point(module_scope)
