# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "common.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0c\x63ommon.proto\x12\x0chazel.rpc.v1"\x16\n\x08\x45ntityId\x12\n\n\x02id\x18\x01 \x01(\x04"\'\n\x04Vec3\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02"2\n\x04Quat\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02"z\n\tTransform\x12$\n\x08position\x18\x01 \x01(\x0b\x32\x12.hazel.rpc.v1.Vec3\x12$\n\x08rotation\x18\x02 \x01(\x0b\x32\x12.hazel.rpc.v1.Quat\x12!\n\x05scale\x18\x03 \x01(\x0b\x32\x12.hazel.rpc.v1.Vec3B\x03\xf8\x01\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "common_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\370\001\001"
    _globals["_ENTITYID"]._serialized_start = 30
    _globals["_ENTITYID"]._serialized_end = 52
    _globals["_VEC3"]._serialized_start = 54
    _globals["_VEC3"]._serialized_end = 93
    _globals["_QUAT"]._serialized_start = 95
    _globals["_QUAT"]._serialized_end = 145
    _globals["_TRANSFORM"]._serialized_start = 147
    _globals["_TRANSFORM"]._serialized_end = 269
# @@protoc_insertion_point(module_scope)
