# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import media_pb2 as media__pb2
from . import viewport_pb2 as viewport__pb2

GRPC_GENERATED_VERSION = "1.76.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(
        GRPC_VERSION, GRPC_GENERATED_VERSION
    )
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + " but the generated code in viewport_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class ViewportServiceStub(object):
    """Streams pixels from a named viewport (useful for external visualization / training input)."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetViewportInfo = channel.unary_unary(
            "/hazel.rpc.v1.ViewportService/GetViewportInfo",
            request_serializer=viewport__pb2.GetViewportInfoRequest.SerializeToString,
            response_deserializer=viewport__pb2.GetViewportInfoResponse.FromString,
            _registered_method=True,
        )
        self.StreamViewport = channel.unary_stream(
            "/hazel.rpc.v1.ViewportService/StreamViewport",
            request_serializer=viewport__pb2.StartViewportStreamRequest.SerializeToString,
            response_deserializer=media__pb2.ImageFrame.FromString,
            _registered_method=True,
        )


class ViewportServiceServicer(object):
    """Streams pixels from a named viewport (useful for external visualization / training input)."""

    def GetViewportInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamViewport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ViewportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetViewportInfo": grpc.unary_unary_rpc_method_handler(
            servicer.GetViewportInfo,
            request_deserializer=viewport__pb2.GetViewportInfoRequest.FromString,
            response_serializer=viewport__pb2.GetViewportInfoResponse.SerializeToString,
        ),
        "StreamViewport": grpc.unary_stream_rpc_method_handler(
            servicer.StreamViewport,
            request_deserializer=viewport__pb2.StartViewportStreamRequest.FromString,
            response_serializer=media__pb2.ImageFrame.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "hazel.rpc.v1.ViewportService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "hazel.rpc.v1.ViewportService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class ViewportService(object):
    """Streams pixels from a named viewport (useful for external visualization / training input)."""

    @staticmethod
    def GetViewportInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/hazel.rpc.v1.ViewportService/GetViewportInfo",
            viewport__pb2.GetViewportInfoRequest.SerializeToString,
            viewport__pb2.GetViewportInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StreamViewport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/hazel.rpc.v1.ViewportService/StreamViewport",
            viewport__pb2.StartViewportStreamRequest.SerializeToString,
            media__pb2.ImageFrame.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
